fn set_draw_tic_tac_toe_game(
txn: Transaction<'_>,
id: i64,
guild_id: MaybeGuildString,
game: TicTacToeGame,
) -> Result<()>Expand description
Set a tic-tac-toe game as a draw as part of a larger transaction, consuming it.
fn set_draw_tic_tac_toe_game(
txn: Transaction<'_>,
id: i64,
guild_id: MaybeGuildString,
game: TicTacToeGame,
) -> Result<()>Set a tic-tac-toe game as a draw as part of a larger transaction, consuming it.